@@ -15,13 +15,15 @@
  */
 package net.morilib.db.engine;
 
+import net.morilib.db.schema.SqlSchema;
+
 public abstract class SqlEngineFactory {
 
 	private static final
 	SqlEngineFactory _INS = new SqlEngineFactory() {
 
-		public SqlEngine getEngine() {
-			return new DefaultSqlEngine();
+		public SqlEngine getEngine(SqlSchema f) {
+			return new DefaultSqlEngine(f);
 		}
 
 	};
@@ -32,6 +34,6 @@ public abstract class SqlEngineFactory {
 		return _INS;
 	}
 
-	public abstract SqlEngine getEngine();
+	public abstract SqlEngine getEngine(SqlSchema f);
 
 }
