@@ -18,20 +18,15 @@ package net.morilib.db.functions;
 import java.sql.SQLException;
 import java.util.List;
 
+import net.morilib.db.delay.Delay;
+import net.morilib.db.expr.RelationExpression;
+import net.morilib.db.expr.RelationFunction;
+import net.morilib.db.misc.Rational;
 import net.morilib.db.relations.RelationAggregate;
-import net.morilib.db.relations.RelationExpression;
-import net.morilib.db.relations.RelationFunction;
 
 public class FnCoalesce extends RelationFunction {
 
-	@Override
-	public boolean isAggregate() {
-		return false;
-	}
-
-	@Override
-	public Object operate(RelationAggregate m, List<Object> group,
-			Object... args) throws SQLException {
+	private static Object nvlx(Object... args) {
 		for(Object o : args) {
 			if(!RelationExpression.isNull(o)) {
 				return o;
@@ -41,8 +36,51 @@ public class FnCoalesce extends RelationFunction {
 	}
 
 	@Override
-	public Object init(RelationAggregate m) throws SQLException {
-		throw new RuntimeException();
+	public boolean isAggregate() {
+		return false;
+	}
+
+	@Override
+	public Object operate(RelationAggregate m, List<Object> group,
+			final Object... args) throws SQLException {
+		boolean f = false;
+
+		for(Object o : args)  f = f || o instanceof Delay;
+		if(f) {
+			Delay d = new Delay() {
+
+				@Override
+				public Object force() throws SQLException {
+					Object[] q = new Object[args.length];
+
+					for(int i = 0; i < q.length; i++) {
+						q[i] = args[i] instanceof Delay ?
+								((Delay)args[i]).force() : args[i];
+					}
+					return nvlx(q);
+				}
+
+				@Override
+				public void add(Object... o) throws SQLException {
+					for(Object x : args) {
+						if(x instanceof Delay) {
+							((Delay)x).add(o);
+						}
+					}
+				}
+
+			};
+
+			m.put(group, d);
+			return d;
+		} else {
+			return nvlx(args);
+		}
+	}
+
+	@Override
+	public Object init() throws SQLException {
+		return Rational.ZERO;
 	}
 
 	@Override
