@@ -16,11 +16,15 @@
 package net.morilib.db.functions;
 
 import java.sql.SQLException;
+import java.util.List;
 
 import net.morilib.db.delay.Delay;
+import net.morilib.db.expr.RelationFunction;
+import net.morilib.db.misc.ErrorBundle;
 import net.morilib.db.misc.Rational;
+import net.morilib.db.relations.RelationAggregate;
 
-public class FnCount extends FnOneValueAggregate {
+public class FnCount extends RelationFunction {
 
 	@Override
 	public Object init() throws SQLException {
@@ -44,9 +48,34 @@ public class FnCount extends FnOneValueAggregate {
 	/* (non-Javadoc)
 	 * @see net.morilib.db.functions.FnOneValueAggregate#getName()
 	 */
-	@Override
 	public String getName() {
 		return "COUNT";
 	}
 
+	@Override
+	public final boolean isAggregate() {
+		return true;
+	}
+
+	@Override
+	public Object operate(RelationAggregate m,
+			List<Object> group,
+			Object... args) throws SQLException {
+		Delay d;
+
+		d = (Delay)m.get(group);
+		if(args.length != 1) {
+			throw ErrorBundle.getDefault(10007, getName());
+		} else if(!args[0].equals("")) {
+			d.add(args[0]);
+		}
+//		m.put(group, d);
+		return d;
+	}
+
+	@Override
+	public FunctionType getType() {
+		return FunctionType.NUMERIC;
+	}
+
 }
